
General encryption support (EXPERIMENTAL)
CONFIG_BLK_DEV_LOOP_GEN
  [1998-12-02]
  If you answer yes to this option, the loop-driver will support all
  crypto algorithms selected in the crypto library (see the 'Crypto'
  menu entry in the main menu).

  This loop module will use the ciphers in CBC-mode which is more
  secure than ECB-mode.  This module will also initialize the CBC-mode
  of the cipher with the block-number of the block being encrypted.

Crypto ciphers
CONFIG_CIPHERS
  Ciphers basically help us scramble data so that other people don't
  get access to it. Useful applications for this include hiding hard
  drive contents or network traffic from unauthorized eyes. Compare a
  file encrypted with a cipher with very good safe: The document is in
  it, you can carry the document with you (if the safe is not too
  heavy), but others can steal it, too. However, they will not be able
  to read the document if the safe is any good.

  Mathematically speaking, a cipher is a parameter-dependant function
  E(K, ) that takes a fixed-length block M (usually 64 or 128 bits)
  and maps it onto another (usually equal-sized) block C=E(K,M) in such
  a way that, without knowledge of the "key" K, it is hard to compute

  1. M, if C and the function E are given,

  2. C, if M is given and the function E is known.

  M is called the 'plaintext' and C the 'ciphertext'. The above
  properties are commonly described as "All the security of the cipher
  lies in its key". However, there always exists the inverse function
  D(K, ) of E(K, ) such that D(K,E(K,M))=M for any M.  The ideal
  cipher is one where it is impossible to compute M if you have C, but
  not K. In this case, the easiest way to break the cipher is to use
  'brute-force', i.e. try all K in turn until you hit the right
  one. With most ciphers in this library, K is a 128-bit number. Here,
  brute-force attacks are infeasible since they require testing all
  2^128 possible keys K, which would take far too long on any
  conceivable computer (some big multiple of the age of the universe
  for example).

  Unfortunately, the ideal cipher has not been found yet, so most
  ciphers in this library, or certain 'reduced-round' versions
  thereof, can be broken faster than brute-force. A cipher is secure,
  if it cannot be broken _much_ faster than brute-force and
  brute-force is infeasible.

  If you say 'Y' or 'M' here, you are able to select a variety of
  ciphers for the Cipher-API. Ciphers you select below can then be
  used by cryptographic kernel modules. If you say 'N' here, those
  modules will use their own implementations or even not work at all.

  If unsure, say 'N'.


Digest algorithms
CONFIG_DIGEST
  A message digest (or 'one-way function' or 'hash') is a function H
  that maps an arbitrary-length message M onto a 128-bit or 160-bit
  number h=H(M) such that the following conditions are satisfied:

  1. For a given M, it is easy to compute h=H(M).

  2. For a given h, it is hard to find M such that h=H(M).

  3. For a given M, it is hard to find another message M' such that
     H(M')=H(M).

  4. It is hard to find M, M' such that H(M)=H(M').

  This makes the name 'one-way function' plausible. Hashes are widely
  used by cryptographic programs. E.g. the Linux kernel uses a hash to
  generate random numbers.

# Marc Mutz <Marc@Mutz.com>: this will be the help text, once this
# functionality is in place:
#  If you say 'Y' here and select the SHA-1 message digest below,
#  then the drivers for /dev/random and /dev/urandom will use the
#  digest api instead of their own implementation. This will not work
#  if you build as modules.
#
  If you say 'Y' or 'M' here, cryptographic modules are able to use
  the Digest-API if they need a hash function. If you say 'N' here,
  they will use their own implementations (which will probably
  increase the size of the compiled kernel if there are more than one
  such modules).

  If unsure, say 'N'.

AES cipher (EXPERIMENTAL - Read Help)
CONFIG_CIPHER_AES
  [2000-10-04]
  DESCRIPTION:
  AES (Advanced Encryption Standard) is a proposed Federal Information
  Processing Standard (FIPS) of the USA. Nevertheless, it was
  conceived by Joan Daemon and Vincent Rijmen, two Belgians, under the
  name Rijndael and submitted to the AES selection process in 1997
  (http://www.nist.gov/aes). On Oct 2, 2000 it was announced as being
  the selected algorithm for the AES.

  Rijndael is a variable-round iterated block cipher that supports
  block and key sizes each ranging from 128 to 256 bits, in steps of
  64. The number of rounds is dependant on the block and key sizes and
  varies from 10 for 128/128 to 14 for 256/256 block/key sizes.
  
  SPPED: N/A

  PATENTS and LICENSING:
  Rijndeal/AES is free of patents. As beign AES, NIST will ensure that
  this will stay so.

  KNOWN ATTACKS:
  None of the following attacks is able to undermine the security of
  AES, when used with the round numbers specified by the authors.

  The original Rijndael specification contains a truncated
  differential attack on 4,5 resp. 6 round versions ("Square attack")
  requiring 2^9, 2^11 resp. 2^32 plaintexts and 2^9, 2^40 resp. 2^72
  work. There is another truncated differential attack that leads to a
  collision attack on 7 round 192 and 256 bit keysize Rijndael
  requiring 2^32 plaintext encryptions and 2^140 work. Other authors
  extend the original Square attack to 7 rounds of 192 and 256 bit
  keysize, both with more that 2^184 work. Further improvements of
  these techniques result in attacks against 7 and 8 round
  variants. But the latter require almost all of the codebook. At
  last, there is a related key attack against 9 round, 256 bit keysize
  Rijndael that requires 2^77 chosen plaintexts and 2^224 work.

AES available under the Rijndael name
CONFIG_CIPHER_RIJNDAEL
  If you say 'Y' here, AES will be also accessible through its
  original name Rijndael. This is mostly for backwards compatibilty.
  If you use kernel modules that use Rijndael, but do not know that it
  is now called AES, say 'Y' here.

  If unsure, say 'N'.

DFC encryption (EXPERIMENTAL - Read Help)
CONFIG_CIPHER_DFC
  [2000-09-13]
  DESCRIPTION:
  DFC (The Decorrelated Fast Cipher) from CNRS and France Telecom is a
  candidate algorithm for the Advanced Encryption Standard (AES).
  It didn't survive the first round of the AES selection, i.e. it is
  not one of the five remaining algorithms in AES round two.

  SPEED: N/A

  PATENTS and LICENSING:
  It is unknown (to me) whether DFC is covered by patents.

  KNOWN ATTACKS:
  I don't know of any attacks, but the problem with this cipher is
  that it was thrown out of the AES competition. This may not mean it
  is a bad cipher, but it certainly means that therefore it has gotten
  _much_ less attention of cryptanalysts. Hence, there may be more
  flaws in it than in the AES finalists.

MARS encryption (EXPERIMENTAL - Read Help)
CONFIG_CIPHER_MARS
  [2000-09-13]
  DESCRIPTION:
  MARS was IBM's candidate algorithm for the Advanded Encryption
  Standard (AES). It consists of 16 core rounds and eight pre-mixing
  as well as eight post-mixing rounds.

  PATENTS and LICENSING:
  Refer to IBM for any copyright, patent or license issues for the
  MARS algorithm.  (However, if this cipher is elected as AES, it has
  to remain/become free for everyone to use)
  NOTE: MARS is covered by patents and might be illegal to use in many
  cases.

  SPEED:
  MARS is a fast algorithm achieving speeds up to 66Mbit on a Pentium
  Pro 200.

  KNOWN ATTACKS:
  As of the Third AES Candidate Conference (Apr. 2000), the best
  attack presented breaks 11 of the 16 core rounds of MARS faster than
  brute-force. This does _not_ mean that MARS is insecure, but shows
  it has design weaknesses. For more information and pointers see
  http://www.counterpane.com/crypto-gram-0004.html#AES-News


RC6 encryption (EXPERIMENTAL - Read Help)
CONFIG_CIPHER_RC6
  [2000-09-13]
  DESCRIPTION:
  RC6 is invented by Ron Rivest and RSA Labs.  It was one of the five
  candidates in round two for the Advanced Encryption Standard (AES).

  PATENTS and LICENSING:
  Refer to RSA Labs and Ron Rivest for any copyright, patent or
  license issues for the RC6 algorithm.
  NOTE: RC6 is covered by patents and might be illegal to use in many
  cases.

  SPEED:
  RC6 is a simple and fast algorithm achieving speeds up to 88Mbit on
  a Pentium Pro 200.  It makes use of multiplication and
  data-dependent rotations which reduces the number of rounds
  necessary and increases its speed (on processors which have fast
  muliplies).

  KNOWN ATTACKS:
  As of the Third AES Candidate Conference (Apr. 2000), 15 of the 20
  rounds of RC6 can be broken faster than brute-force. This does _not_
  mean that RC6 is insecure, but shows it has design weaknesses. For
  more information and pointers see
  http://www.counterpane.com/crypto-gram-0004.html#AES-News

Serpent encryption
CONFIG_CIPHER_SERPENT
  [1998-10-13]
  DESCRIPTION:
  Serpent is a 128-bit block cipher designed by Ross Anderson, Eli
  Biham and Lars Knudsen as a candidate for the Advanced Encryption
  Standard (AES, see http://www.nist.gov/aes).  It was one of the five
  finalists after round two of the AES candidate search. Serpent
  provides users with the highest practical level of assurance that no
  shortcut attack will be found.  To achieve this, the algorithm uses
  well understood mechanisms so that its security relies on the wide
  experience of block cipher cryptoanalysis.  The algorithm uses twice
  as many rounds as are necessary to block all currently known
  shortcut attacks.  The algorithm is designed to have a service life
  of 50 years and to continue to protect legacy data for a further 50
  years beyond that.

  SPEED:
  Despite these exacting design constraints, Serpent is faster than
  DES. Its design supports a very efficient bitslice implementation,
  and this implementation runs at almost 25 Mbit/sec on a
  200MHz Pentium (compared with about 15 Mbit/sec for DES). However,
  compared to competitors for AES left in round two, it is painfully
  slow to implement in software.

  PATENTS and LICENSING:
  Serpent is completely in the public domain, and no restrictions are
  imposed on its use.

  KNOWN ATTACKS:
  As of the Third AES Candidate Conference (Apr. 2000), 9 of the 32
  rounds of Serpent can be broken faster than brute-force. This does
  _not_ mean that Serpent is insecure, but shows it has design
  weaknesses. For more information and pointers see
  http://www.counterpane.com/crypto-gram-0004.html#AES-News

  More information about Serpent:
  http://www.cl.cam.ac.uk/~rja14/serpent.html

  More information about the implementation:
  http://www.seven77.demon.co.uk/crypto_technology.htm

CAST 128 encryption
CONFIG_BLK_DEV_LOOP_CAST
  This module implements CAST-128.  The algorithm
  was published in RFC 2144 as a proposed Internet standard, and is
  from Entrust (http://www.entrust.com/) a Canadian company.

  This loop module uses the weak ECB-mode which means that it is more
  open to certain attacks than CBC-mode ciphers. 

IDEA encryption
CONFIG_CIPHER_IDEA
  [2000-09-13]
  DESCRIPTION:
  IDEA is a 64-bit block cipher designed by Xuejia Lai and James
  Massey in 1992. It uses a 128-bit key and eight rounds with a round
  function that mixes three---generally incompatible---algebraic
  groups: XOR, addition mod 2^16 and multiplication mod 2^16-1.

  SPEED:
  IDEA should be quite fast on CPU's that have a fast multiplication
  instruction (beware that the Pentium IV processor is quite poorly
  equipped in this area w.r.t its predecessors).

  PATENTS and LICENSING:
  The IDEA code is mostly from ASCOM (http://www.ascom.com/) and
  licensed for non-commercial use.

  This module may contain algorithms which are patented, and/or
  require licensing for commerical use. Please read crypto/idea.c for
  details.

  KNOWN ATTACKS:
  As of 1995, the most successful attack broke two of the eight rounds
  of IDEA. Since then, I strongly believe in the existence of better
  attacks, but you should search the literature to be sure.

MD5 digest (EXPERIMENTAL)
CONFIG_DIGEST_MD5
  [2000-09-13]
  MD5 once was the most widely used hash function, until it was shown
  that MD5 is not collision-resistant, i.e., you can find messages M,
  M', such that MD5(M)=MD5(M') faster than brute-force. This is called
  a "birthday attack", named after the birthday paradox. Although this
  is not a security problem per se, it is still something a
  cryptographically strong hash function should not exhibit.

  Don't use MD5 anymore, except to support legacy applications (of
  which there should not be too many, since the digest API is
  relatively new) and for fingerprinting files, something that was
  better done in user space.

SHA1 digest (EXPERIMENTAL)
CONFIG_DIGEST_SHA1
  [2000-09-13]
  SHA-1 is currently the most widely deployed hash function. Although
  designed by the NSA it is generally believed to not contain back
  doors and be the most secure message digest available today. If you
  want to use a cryptographically secure hash function, use SHA-1.

Twofish encryption (only as module)
CONFIG_BLK_DEV_LOOP_FISH2
  DESCRIPTION:
  Twofish is a quite new algorithm invented by Bruce Schneier, Doug
  Whiting, John Kelsey, Chris Hall and David Wagner, for more
  information see http://www.counterpane.com/twofish.html. It is one of
  the remaining five candidates for the Advanced Encryption
  Standard (AES). Blowfish is the older algorithm and was also
  invented by Bruce Schneier.

  SPEED: N/A

  PATENTS and LICENSING:
  Both algorithms are free of licensing charges at the moment. Twofish
  must remain so if it is elected as AES winner.

  KNOWN ATTACKS:
  to be written

  This module operates twofish in CBC-mode

Blowfish encryption (EXPERIMENTAL)
CONFIG_CIPHER_BLOWFISH
  [2000-09-13]
  DESCRIPTION:
  Blowfish is an algorithm invented by Bruce Schneier.  For more
  information about the algorithm see
  http://www.counterpane.com/blowfish.html or see Schneier's book
  "Applied Cryptography", chapter 13.4. Twofish is the newer algorithm
  and was also invented by Bruce Schneier (et al.).

  SPEED:
  Blowfish is a very efficient cipher on 32-bit microprocessors. In
  fact, I guess it is the fastest available for the Linux Crypto API
  as of now. Definitive figures should be added here...

  PATENTS and LICENSEING:
  Blowfish is free of patents and licensing charges and Schneier says
  it will stay that way.

  KNOWN ATTACKS:
  to be written

Network Block Device support
CONFIG_BLK_DEV_NBD
  Saying Y here will allow your computer to be a client for network
  block devices, i.e. it will be able to use block devices exported by
  servers (mount file systems on them etc.). Communication between
  client and server works over TCP/IP networking, but to the client
  program this is hidden: it looks like a regular local file access to

